# 
# Some Useful Autoconf macros for configuring SDSCSyslog (and possibly
# other programs as well).
#
# Author: Varies, see macro definition.
#
# $Id: acinclude.m4,v 1.3.2.1 2003/04/30 20:02:56 devink Exp $
#
# Copyright 2002-2003 
#     The Regents of the University of California. All Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
# 
#     * Neither the name of the The Regents of the University of
#       California nor the names of its contributors may be used to
#       endorse or promote products derived from this software without
#       specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# SDSC_FUNC_SNPRINTF
#   Check for a working snprintf().  There are two different versions of
#   which are checked for.  First is reasonable behavior (i.e. won't
#   overflow a buffer), second is C99 compliance.  
#   Defines: HAVE_SNPRINTF -- if there is a snprintf present
#            SNPRINTF_C99 -- snprintf conforms to the C99 spec.
#              
# Author: Devin Kowatch
AC_DEFUN([SDSC_FUNC_SNPRINTF],
[
AC_MSG_CHECKING([for working snprintf])
HAVE_SNPRINTF=0
HAVE_WORKING_SNPRINTF=0
SNPRINTF_NILTERM=0
SNPRINTF_C99=0
AH_TEMPLATE([HAVE_SNPRINTF], [Define if you have the `snprintf' function.])
AH_TEMPLATE([SNPRINTF_C99], 
    [Define if you have a C99 conformant 'spnrintf' function])
# Check that snprintf exists
AC_TRY_LINK_FUNC(snprintf, HAVE_SNPRINTF=1)
if test "$HAVE_SNPRINTF" = "0" ; then
    AC_MSG_RESULT([no])
    AC_MSG_ERROR([$PACKAGE_NAME requires a working snprintf])
fi
# Check that it really works
AC_TRY_RUN([
    int main() {
        char    b[10];
        int     i;
        for (i = 0; i < 10; i++) {
            b[i] = '\0';
        }

        snprintf(b, 5, "01234567");
        /* char after last is set, there was a problem */
        if (b[5] == '5') return -1;
        return 0;
    }], [HAVE_WORKING_SNPRINTF=1])
# Check that it terminates with '\0'
AC_TRY_RUN([
    int main() {
        char    b[10];
        int     i;
        for (i = 0; i < 10; i++) b[i] = '\0';

        snprintf(b, 5, "0123456789");
        if (b[4] != '\0') return -1;
        return 0;
    }
    ], [SNPRINTF_NILTERM=1])
if test "$HAVE_WORKING_SNPRINTF" = "0" -o "$SNPRINTF_NILTERM" = "0" ; then
    AC_MSG_RESULT([not functional])
    AC_MSG_ERROR([$PACKAGE_NAME requires a working snprintf])
fi
# Check for C99 return value
AC_TRY_RUN([
    int main() {
        char    b[10];
        int     i;
        i = snprintf(b, 5, "0123456789");
        if (i != 10) return -1;
        return 0;
    }], [SNPRINTF_C99=1])

if test "$SNPRINTF_C99" = "1" ; then
    AC_DEFINE([SNPRINTF_C99])
else
    # The return code is too wierd to cope with. failing...
    AC_MSG_RESULT([return incorrect])
    AC_MSG_ERROR([$PACKAGE_NAME requires a working snprintf])
fi
AC_MSG_RESULT([yes])
AC_DEFINE([HAVE_SNPRINTF])
])

# SDSC_DEF_O_NOFOLLOW
#   Check for a working definition of O_NOFOLLOW.
#
#   Under Linux O_NOFOLLOW may be defined, but only works for 
#   kernels >= 2.1.126
#
#   Defines: HAVE_O_NOFOLLOW -- if O_NOFOLLOW is defined and should work.
#
AC_DEFUN([SDSC_DEF_O_NOFOLLOW], 
[
AC_MSG_CHECKING([for working O_NOFOLLOW define])
HAVE_O_NOFOLLOW=0
AH_TEMPLATE([HAVE_O_NOFOLLOW], [Define if you have a working O_NOFOLLOW])

AC_TRY_COMPILE(
[
#define _GNU_SOURCE
#include <sys/types.h>
#include <sys/stat.h> 
#include <fcntl.h>

#ifndef O_NOFOLLOW
#error O_NOFOLLOW not defined
#endif], [], [HAVE_O_NOFOLLOW=1])

if test "$HAVE_O_NOFOLLOW" = "1" ; then
    case `uname -s -r` in
        "Linux 2.1."*) HAVE_O_NOFOLLOW = 0 ;;
        "Linux 2.0."*) HAVE_O_NOFOLLOW = 0 ;;
        "Linux 1."*) HAVE_O_NOFOLLOW = 0 ;;
        "Linux 0."*) HAVE_O_NOFOLLOW = 0 ;;
    esac
fi

if test "$HAVE_O_NOFOLLOW" = "1" ; then
    AC_MSG_RESULT([yes])
else
    AC_MSG_RESULT([no])
fi
AC_DEFINE([HAVE_O_NOFOLLOW])
])

