#
# File: find_tools.sh
#
# Descriptions:
#   This file cotains some functios for finding the autoconf/automake tools.  
#   It is :a separate file because these functions are used by several
#   scripts.
#
# $Id: find_tools.sh,v 1.3.2.3 2003/04/30 20:03:00 devink Exp $
#
# Author: Devin Kowatch
# Date: Mon Aug 05 21:40 PDT 2002
#
# Copyright 2002-2003 
#     The Regents of the University of California. All Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
# 
#     * Neither the name of the The Regents of the University of
#       California nor the names of its contributors may be used to
#       endorse or promote products derived from this software without
#       specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# See COPYING for lcense details
#

ACLOCAL=""
AUTOHEADER=""
AUTOCONF=""
AUTOMAKE=""

# Try to find a version of autoconf greater than or equal to the
# required version in the given directory.
# Usage: find_autotool_path $dir $tool_name $req_major $req_minor
# Return good exit (0) on success, error otherwise.
# On good exit the path is in $atpath
find_autotool_path () {
    paths=`ls -1 $1/${2}* 2> /dev/null` 
    for atpath in $paths ; do
        if test -x "$atpath" ; then
            version=`$atpath --version 2> /dev/null | grep "$2 (GNU"` 
            major=""
            minor=""
            if test "x$version" != "x" ; then
                major=`echo $version | sed 's,.* \([0-9]*\)\..*,\1,'`
                minor=`echo $version | sed 's,.* \([0-9]*\)\.\([0-9]*\).*,\2,'`
            fi

            if test "X$major" != "x" && test "x$minor" != "x" \
                && test "$major" -ge $3 && test "$minor" -ge $4 
            then
                return 0
            fi
        fi
    done
    return 1
}

# This takes a full path to one of the autotools and converts it to
# another in the same family.
# Final result is in $atpath
conv_prog () {
    local dir base

    base=`basename $1 | sed "s,$2\(.*\),$3\1,"`
    dir=`dirname $1` 

    atpath="$dir/$base"
}


#
# Try to set AUTOMAKE, AUTOCONF, ACLOCAL, AUTOHEADER to correct paths
# We first check for the odd path b/c that's what we use for new versions of
# automake/autoconf at SDSC, and it makes *my* life easier if the script can
# figure that out.  If we don't have that odd path, we use the default path
# to try to find out where they are.
#
find_autotools() {

    searchdirs=`echo $PATH | sed 's,:, ,g'`
    searchdirs="/usr/local/apps/automake-1.5/bin $searchdirs"
    searchdirs="/usr/local/apps/autoconf-2.52/bin $searchdirs" 
    for dir in $searchdirs ; do
        if test x"$AUTOMAKE" = x ; then
            if find_autotool_path $dir "automake" "1" "5"; then
                AUTOMAKE=$atpath

                conv_prog $AUTOMAKE "automake" "aclocal"
                ACLOCAL=$atpath

                test x"$have_logging" = x"yes" \
                    && (log "found automake at $AUTOMAKE" ; \
                        log "found aclocal at $ACLOCAL")
            fi
        fi

        if test x"$AUTOCONF" = x ; then
            if find_autotool_path $dir "autoconf" "2" "52"; then
                AUTOCONF="$atpath"

                conv_prog $AUTOCONF "autoconf" "autoheader"
                AUTOHEADER=$atpath

                test x"$have_logging" = x"yes" \
                    && (log "found autoconf at $AUTOCONF" ; \
                        log "found autoheader at $AUTOHEADER")
            fi
        fi

        unset atpath
    done

    unset seachdirs dirs

    if test x"$AUTOCONF" = x -o x"$AUTOMAKE" = x \
            -o x"$AUTOHEADER" = x -o x"$ACLOCAL" = x
    then
	if test x"$AUTOCONF" = x
	then
		echo "Failed to find autoconf"
	fi

	if test x"$AUTOMAKE" = x
	then
		echo "Failed to find automake"
	fi

	if test x"$AUTOHEADER" = x
	then
		echo "Failed to find autoheader"
	fi

	if test x"$ACLOCAL" = x
	then
		echo "Failed to find aclocal"
	fi

        return 1
    fi

    return 0
}
