# 
# File: func.sh
#
#
# Description: Support functions used by all the rel sup scripts.
#
# $Id: func.sh,v 1.5.2.1 2003/04/30 20:03:00 devink Exp $
#
# Author: Devin Kowatch <devink@sdsc.edu>
# Date: Tue May 28 17:18:31 PDT 2002
#
# Copyright 2002-2003 
#     The Regents of the University of California. All Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
# 
#     * Neither the name of the The Regents of the University of
#       California nor the names of its contributors may be used to
#       endorse or promote products derived from this software without
#       specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# We need these
FIND_TOOLS="relsup/find_tools.sh"
test -r "$FIND_TOOLS" || (echo "Can't find \"find_tools.sh\" " 1>&2; exit 1)
. $FIND_TOOLS

stdout=1
stderr=2
logging=no

# You can check this to see if the file has been sourced yet.
have_logging=yes

#
# Exit with an error return (1) and an error message
#
fatal () {
    echo "Error: $1" 1>&$stderr
    if test x"$logging" = x"yes" ; then
        echo "Error: $1" 
    fi
    exit 1
}

#
# Run the program or die with an error.
#
run_or_die () {
    test x"$1" != x || fatal "No program to run specified"
    pname=`basename $1`
    log "Running $1"
    $1 || fatal "Running program $pname" 
}

#
# Log all normal (non fatal() generated) output to a file
#
set_log_file () {
    # save STDOUT/STDERR
    exec 3>&1
    exec 4>&1

    stdout=3
    stderr=4

    # redirect stdout/stderr
    exec 1> $1
    exec 2>&1

    logging=yes
}

#
# Turn logging to a file off
#
unset_log_file () {
    exec 1>&$stdout
    exec 2>&$stderr
}

#
# Log a message
#
log () {
    echo "$1"
}
        

