#!/bin/sh
###########################################################################
# File: make_build_files.sh
#
#
# Description: 
#   Make the build system files which are not stored in CVS.  This means
#   all the Makefile.in files, aclocal, configure, etc...
#
# $Id: make_build_files.sh,v 1.8.2.1 2003/04/30 20:03:01 devink Exp $
#
# Author: Devin Kowatch <devink@sdsc.edu>
# Date: Tue May 28 17:04:46 PDT 2002
#
# Copyright 2002-2003 
#     The Regents of the University of California. All Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
# 
#     * Neither the name of the The Regents of the University of
#       California nor the names of its contributors may be used to
#       endorse or promote products derived from this software without
#       specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
############################################################################


#set -x

# List of extra configure domains ... could be determined from
# configure.ac if I were motivated.
config_subdirs=`grep AC_CONFIG_SUBDIRS configure.ac`
INCLUDED_PKGS=`echo $config_subdirs \
	| sed -e 's/AC_CONFIG_SUBDIRS//g' \
	| sed -e 's/(//g' \
	| sed -e 's/)//g' \
	| sed -e 's/\[//g' \
	| sed -e 's/\]//g' \
	| sed -e 's/\,//g'`
unset config_subdirs

LOG="L.make.buildsup"

FUNCS="relsup/func.sh"
test -r "$FUNCS" || (echo "Can't find support functions" 1>&2; exit 1)
. $FUNCS

# we need to be in the root directory of the sdscsyslog tree 
test -f "configure.ac" || fatal "Working Directory is messed up" 

# send STDOUT/STDERR to a file
set_log_file $LOG

# figure out which automake/autoconf tools to use.
find_autotools || fatal "Can't find all of the needed tools"

run_or_die $ACLOCAL
run_or_die $AUTOHEADER 
run_or_die $AUTOMAKE
run_or_die $AUTOCONF 

for dir in $INCLUDED_PKGS ; do

    pushd $dir > /dev/null 2>&1
    log ""
    log "Entering $dir ..."


    if test -r "configure.in" ; then
        configure_ac="configure.in"
    elif test -r "configure.ac" ; then
        configure_ac="configure.ac"
    else
        fatal "Can't Find configure input file"
    fi

    if grep AM_CONFIG_HEADER $configure_ac > /dev/null 2>&1 ; then
		run_or_die $AUTOHEADER 
	fi

    if grep AM_INIT_AUTOMAKE $configure_ac > /dev/null 2>&1 ; then
        run_or_die $ACLOCAL
		run_or_die $AUTOMAKE
	fi

    run_or_die $AUTOCONF 

    log "Leaving $dir."
    popd > /dev/null 2>&1
done

# Now collect the interesting errors and print them
unset_log_file

echo "Error Report: "
echo "--------------"

egrep "(warning|error)" $LOG \
    | grep -v "AC_PROG_LEX invoked multiple" \
    | egrep -v "do not use (m4_regexp|m4_patsubst)"

echo
