# 
# File: tag_funcs.sh
#
#
# Description: Functions for manipulating tags
#
# $Id: tag_funcs.sh,v 1.1.2.7 2003/04/30 20:03:01 devink Exp $
#
# Author: Devin Kowatch <devink@sdsc.edu>
# Date: Mon Aug 19 16:25:30 PDT 2002
#
# Copyright 2002-2003 
#     The Regents of the University of California. All Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
# 
#     * Neither the name of the The Regents of the University of
#       California nor the names of its contributors may be used to
#       endorse or promote products derived from this software without
#       specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# Shared constants
TAG_PREFIX="SYSLOGD"

# REs to match various types of tags.  Must work in awk and sed
RE_DIG="[0-9][0-9]*"
TAGRE_RELEASE="${TAG_PREFIX}_${RE_DIG}_${RE_DIG}_${RE_DIG}_RELEASE"
TAGRE_RC="${TAG_PREFIX}_${RE_DIG}_${RE_DIG}_${RE_DIG}_RC${RE_DIG}"
TAGRE_PATCH="${TAG_PREFIX}_${RE_DIG}_${RE_DIG}"
TAGRE_STABLE="${TAG_PREFIX}_${RE_DIG}"


# Check a version for valid formatting
not_valid_version ()
{
    local verchk

    verchk=`echo $1 | sed "s/$RE_DIG\.$RE_DIG\.$RE_DIG//"`
    test "x$verchk" = "x" && return 1   # its good (so return !true)

    return 0    # no so good (return !false)
}

# Check a release canidate number for validity.
not_valid_rcnum ()
{
    local rcchk

    rcchk=`echo $1 | sed "s/$RE_DIG//"`
    test "x$rcchk" = "x" && return 1    # its good (return !true)

    return 0    # invalid (return !false)
}

# echo a string containing the tag based on the version
make_version_tag ()
{
    local post tag

    tag=`echo $1 | sed 's/\./_/g'`
    tag="${TAG_PREFIX}_${tag}"
    if test "x$2" = "xrelease" ; then
        post="_RELEASE"
    elif test "x$2" = "xstable" ; then
        tag=`echo $tag | sed "s/\($TAGRE_STABLE\)[_0-9]*/\1/"`
    elif test "x$2" = "xpatch" ; then
        tag=`echo $tag | sed "s/\($TAGRE_PATCH\)[_0-9]*/\1/"`
    elif test "x$2" != "x" ; then
        post="_RC$2"
    fi

    echo "${tag}${post}"
}

version_inc_branch ()
{
    local   version head_version tmp
    local   branch_var

    branch_var="${1}_ver"

    # Temp files yes
    tmp=`mktemp VERSION.tmpXXXXXX` || return 1

    # Get the new version for the branch
    version=`echo $2 | sed "s/${TAG_PREFIX}_//"`

    # If this is a new stable branch then we need a new head version
    # also, so figure out what it is
    if test "x$1" = "xstable" ; then
        # $version will be a signgle digit, and head version is always
        # 1+ that.  Using awk was the most portable way I can think of
        # doing it.
        head_version=`echo $version | awk '{print $1 + 1}'`
        grep -v "$branch_var" VERSION | grep -v "head_ver" > $tmp
        echo "head_ver=\"$head_version\"" >> $tmp
    else
        grep -v "$branch_var" VERSION > $tmp
    fi

    echo "${branch_var}=\"$version\"" >> $tmp
    mv $tmp VERSION

    return 0
}

version_change_branch ()
{
    local tmp 

    tmp=`mktemp VERSION.tmpXXXXXX` || return 1

    grep -v "BRANCH" VERSION > $tmp
    echo "BRANCH=\"$1\"" >> $tmp
    mv $tmp VERSION

    return 0
}






