#!/bin/sh
# 
# File: update.sh
#
#
# Description: Update the source tree.  This assumes that you have a CVS
# tree and are in the root directory if it.
#
# $Id: update.sh,v 1.10.2.1 2003/04/30 20:03:01 devink Exp $
#
# Author: Devin Kowatch <devink@sdsc.edu>
# Date: Wed May 29 12:03:51 PDT 2002
#
# Copyright 2002-2003 
#     The Regents of the University of California. All Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
# 
#     * Neither the name of the The Regents of the University of
#       California nor the names of its contributors may be used to
#       endorse or promote products derived from this software without
#       specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


#set -x

UPDATE_LOG="L.update"

# Make sure that we have a cvs tree.
test -d "CVS" || fatal "Can't find a CVS directory"
test -f "configure.ac" \
    || fatal "You don't appear to be in the correct directory"

(cvs update -Pd 2>&1 | tee $UPDATE_LOG) || fatal "cvs update failed"

echo
echo "General Activity:"
echo "-----------------"
egrep "^[UPARM] " $UPDATE_LOG | sort
egrep "no longer in repository" $UPDATE_LOG | sed -e 's/cvs server: *//'

echo 
echo "Files that might need adding:"
echo "-----------------------------"
egrep "^\?" $UPDATE_LOG | awk '{print $2}'          \
    | egrep "(\.c|\.h|\.y|\.l|\.sh|README.*|\.am|\.in|\.dtd|\.act)$"  \
    | egrep -v "Makefile.in$"                       \
    | egrep -v "(acconfig\.h|check/config\.h)"      \
    | egrep -v "(confparse.[ch]|conflex.c)"         \
	| egrep -v "(const.h$|version.h$)"


echo
echo "Conflicts:"
echo "----------"
grep "^C " $UPDATE_LOG | awk '{print $2}' 
