/**
 * @file config.c
 *
 * @brief Create the public config functions (as defined in config.h)
 *
 *
 * $Id: config.c,v 1.8.2.6 2003/04/30 20:03:06 devink Exp $
 *
 * @author Matt Small <small@sdsc.edu>
 * @date   Thu Apr 25 14:21:06 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "types.h"
#include "chaninfo.h"
#include "conf_obj.h"
#include "config.h"
#include "conf_private.h"

static char const rcsid[] = "$Id: config.c,v 1.8.2.6 2003/04/30 20:03:06 devink Exp $";

static int conf_sdsc_already_run=0;

struct config_info * 
getConfigInfo(char const *file)
{
	FILE *fp;
	struct config_info *ret;

	/* try to open the file */
	fp=fopen(file,"r");
	if(NULL==fp)
	{
		printf("error: could not open file %s\n",file);
		return NULL;
	}

	/* if we've already run the parser, call yyreset(); if not, just yyprep() */
	if(conf_sdsc_already_run)
	{
		yyreset(fp,(char *)file);
	}
	else yyprep(fp,(char *)file);

	/* parse the file */
	if(0!=yyparse())
	{
		yystop();

		conf_sdsc_already_run=1;
		CONFSYM_destroy();

		return NULL;
	}
	ret=CONFSYM_getInfo();
	yystop();

#ifdef DUMP_CONFIG_INFO
	printf("dumping ret...\n");
	dump_config_info(ret);
#endif

	conf_sdsc_already_run=1;

	return ret;
}

void 
destroyConfigInfo(struct config_info **obj)
{
	CONFOBJ_destroyInfo(obj);
}
