/**
 * @file priority.h
 *
 * @brief List all of the external severities and facilities used by
 * syslog.
 *
 * $Id: priority.h,v 1.5.2.6 2003/04/30 20:03:07 devink Exp $
 *
 * @author Matt Small <small@sdsc.edu>
 * @date   Wed May 22 11:58:02 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef CONFIG_PRIORITY_H
#define CONFIG_PRIORITY_H

/**@name Message Severities
 * @ingroup conf
 * @{
 */

/** Severities */
#define     CONFFS_NONE     -1      /**< config only, ignore a facility */
#define		CONFFS_EMERG	0		/**< Emergency severity */
#define		CONFFS_ALERT	1		/**< Alert severity */
#define		CONFFS_CRIT		2		/**< Critical severity */
#define     CONFFS_ERR		3		/**< Error severity */
#define     CONFFS_WARN		4		/**< Warning severity */
#define     CONFFS_NOTICE	5		/**< Notice severity */
#define     CONFFS_INFO		6		/**< Informational severity */
#define     CONFFS_DEBUG	7		/**< Debug severity */

/** Largest numbered severity + 1 */
#define     CONFFS_SEVCOUNT 8

/*@}*/

/**@name Message Facilities
 * @ingroup conf
 * @{
 */
#define		CONFFS_KERN		0		/**< Kernel facility */
#define		CONFFS_USER		1		/**< User facility */
#define		CONFFS_MAIL		2		/**< Mail facility */
#define		CONFFS_DAEMON	3		/**< Daemon facility */
#define		CONFFS_AUTH0	4		/**< Auth facility (first one) */
#define		CONFFS_SYSLOG	5		/**< Syslog facility */
#define		CONFFS_LPR		6		/**< LPR facility */
#define		CONFFS_NEWS		7		/**< News facility */
#define		CONFFS_UUCP		8		/**< UUCP facility */
#define		CONFFS_CRON0	9		/**< Cron facility (first one) */
#define		CONFFS_AUTH1	10		/**< Auth facility (second one */
#define		CONFFS_FTP		11		/**< FTP facility */
#define		CONFFS_NTP		12		/**< NTP facility */
#define		CONFFS_AUDIT0	13		/**< Audit facility (first one) */
#define		CONFFS_AUDIT1	14		/**< Audit facility (second one) */
#define		CONFFS_CRON1	15		/**< Cron facility (second one) */
#define		CONFFS_LOCAL0	16		/**< First local facility */
#define		CONFFS_LOCAL1	17		/**< Second local facility */
#define		CONFFS_LOCAL2	18		/**< Third local facility */
#define		CONFFS_LOCAL3	19		/**< Fourth local facility */
#define		CONFFS_LOCAL4	20		/**< Fifth local facility */
#define		CONFFS_LOCAL5	21		/**< Sixth local facility */
#define		CONFFS_LOCAL6	22		/**< Seventh local facility */
#define		CONFFS_LOCAL7	23		/**< Eighth local facility */
#define     CONFFS_MARK     24      /**< INTERNAL: mark messages */

/** Largest numbered facility + 1 */
#define     CONFFS_FACCOUNT 25

/*@}*/

#endif /* CONFIG_PRIORITY_H */
