/**
 * @file ctlr_destroy.h
 *
 * @brief Functions for a multi-stage destruction of the controller.  
 * @par
 * There are many functions here so that parts of the controller
 * shutdown can be selectivly done.
 *
 * $Id: ctlr_destroy.h,v 1.1.2.1 2003/04/30 20:03:10 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Tue Jul 02 13:35:48 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef CTLR_CTLR_DESTROY_H
#define CTLR_CTLR_DESTROY_H

#include "controller.h"

/**
 * Kill all input modules via SIGTERM.
 *
 * @param ctlr The CTLR object to work on.
 */
void CTLR_killIMs(CTLR *ctlr);

/**
 * Destroy all output modules.
 *
 * @param ctlr The CTLR object to work on.
 */
void CTLR_destroyOMs(CTLR *ctlr);

/**
 * Shutdown the IPC handle.
 *
 * @param ctlr The CTLR object to work on.
 */
inline void CTLR_shutdownIPC(CTLR *ctlr);

/**
 * Shutdown the Listening sockets.
 *
 * @param ctlr The CTLR object to work on.
 */
void CTLR_shutdownSockets(CTLR *ctlr);

/**
 * Free any malloc'ed memory.
 *
 * @param ctlr The CTLR object to work on.
 */
void CTLR_freeMemory(CTLR *ctlr);

#endif /* CTLR_CTLR_DESTROY_H */
