/**
 * @file chaninfo.h
 *
 * @brief Structures which keep track of channel info.  
 * @par
 * These are shared beteween the controller and config modules.
 *
 *
 * $Id: chaninfo.h,v 1.4.2.1 2003/04/30 20:03:12 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Thu Jul 18 13:34:28 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef INC_CHANINFO_H
#define INC_CHANINFO_H

#include "outputmod/outputmod.h"
#include "inputmod/inputmod.h"
#include "util/acl.h"
#include "util/netaddr.h"
#include "const.h"
#include "types.h"

/**@defgroup chaninfo Channel Info
 * @{
 */

/** Input Channel Information */
struct inchan_info
{
    char        *name;      /**< channel name, must be free()ed */
    uint32_t    id;         /**< channel id */
    IMOD_TYPE   type;       /**< channel type */

	netaddr_t	inAddr;		/**< Addess to listen at */
	char *		inPath;		/**< Path (as a char *) to listen at */
    int			inPort;		/**< listen port */

    ACL         *path_acl;  /**< Path check ACL (\ref d2_2_1) */
    ACL         *psec_acl;  /**< Path security ACL (\ref d2_2_2) */
    ACL         *hsrc_acl;  /**< Generating host ACL (\ref d2_2_3) */
    ACL         *hcon_acl;  /**< Connecting host ACL (\ref d2_2_4) */

    int         fd;         /**< channel listen socket */
};

/** Output Channel Information */
struct outchan_info
{
    char        *name;      /**< channel name, must be free()ed */
    uint32_t    id;         /**< channel id */
    OMOD_TYPE   type;       /**< channel type */

    struct OMOD_opt *opts;  /**< channel options */

    /**@todo make this a bit array */
    uint8_t     pri[PRIORITY_COUNT];    /**< priorities this OC handles*/

    OMOD_interface  *iface;             /**< OM interface for this channel */
};

/*@}*/

#endif /* INC_CHANINFO_H */
