/**
 * @file dmalloc_sup.h
 *
 * @brief dmalloc support macros.
 * @par
 * This defines a bunch of macros that support dmalloc, as well as
 * including the dmalloc header.  This should be the last header
 * included in the file, and requires that acconfig.h is included before
 * it.
 *
 * $Id: dmalloc_sup.h,v 1.1.2.2 2003/04/30 20:03:12 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Wed Jan 29 10:58:01 PST 2003
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**@define DMALLOC_PARAMS(...)
 * Define extra parameters to pass info that dmalloc needs down the
 * stack.  I try to avoid using this, as it's a bit ugly, but sometimes
 * needed.  It is used in function decls, example:
 * \code
 *   void foo DMALLOC_PARAMS(int arg1, char *arg2) 
 * \endcode
 * This will add parameter names 'dmfile' and 'dmline' which are the
 * file and line, respectively, of the position the function was called,
 * don't forget to make arragements to actually pass this info.
 *
 * @see DMALLOC_ARGS
 */

/**@define DMALLOC_ARGS(...)
 * Pass file and line info only when dmalloc is in use.
 */
#if WITH_DMALLOC
#   define DMS_PARAMS(...)  char const *dmfile, int dmline, __VA_ARGS__
#   define DMS_EMPTY_PARAMS char const *dmfile, int dmline

#   define DMS_ARGS(dmf, dml, ...)  dmf, dml, __VA_ARGS__
#   define DMS_EMPTY_ARGS(dmf, dml) dmf, dml

#   define DMSmalloc(sz)   errorMalloc(dmfile, dmline, sz)
#else
#   define DMS_PARAMS(...)  __VA_ARGS__
#   define DMS_EMPTY_PARAMS void

#   define DMS_ARGS(dmf, dml, ...)  __VA_ARGS__
#   define DMS_EMPTY_ARGS(dmf, dml) /* empty */

#   define DMSmalloc(sz)   errorMalloc(__FILE__, __LINE__, sz)
#endif
