/**
 * @file strcompat.h
 *
 * @brief This file is declares functions and types which are missing
 * from some versions of Unix/Linux but present in others.  
 * @par
 *
 *
 * $Id: strcompat.h,v 1.1.2.1 2003/04/30 20:03:13 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Tue Feb 26 17:06:41 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef COMPAT_STRING_H
#define COMPAT_STRING_H


/**@defgroup compat Compatibility Functions.  
 * These are used to replace functions that are missing in some 
 * platforms which SDSCSyslog is ported to.  They will only be used 
 * if needed, and are turned on/off by autoconf.
 * @{
 */

#ifdef HAVE_CONFIG_H
#   include "acconfig.h"
#endif

/* means we only need to include our string.h */
#include <string.h>

#ifndef HAVE_STRLCAT
/**
 * Appends src to string \c dst of size \c siz (unlike strncat, \c siz is the
 * full size of \c dst, not space left).  At most \c siz-1 characters
 * will be copied.  Always NUL terminates (unless \c siz <= strlen(\c dst)).
 *
 * @param dst The destination buffer
 * @param src The source buffer
 * @param siz The size of \c dst
 * @return strlen(\c src) + MIN(\c siz, strlen(initial dst)).  
 *      If retval >= \c siz, truncation occurred.
 */
size_t strlcat(char *dst, char const *src, size_t siz);
#endif


#ifndef HAVE_STRLCPY
/**
 * Copy \c src to string \c dst of size \c siz.  At most \c siz-1 characters
 * will be copied.  Always NUL terminates (unless \c siz == 0).
 *
 * @param dst The destination buffer
 * @param src The source buffer
 * @param siz The size of \c dst
 * @return strlen(\c src); if retval >= \c siz, truncation occurred.
 */
size_t strlcpy(char *dst, char const *src, size_t siz);
#endif 

/*@}*/

#endif /* COMPAT_STRING_H */
