/**
 * @file inputmod.c
 *
 * @brief Some input module support stuff.
 *
 * $Id: inputmod.c,v 1.2.2.6 2003/04/30 20:03:16 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Wed Jul 17 13:44:27 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <unistd.h>
#include <netdb.h>

#include "error.h"
#include "strcompat.h"

#include "inputmod.h"

static char const rcsid[] 
    = "$Id: inputmod.c,v 1.2.2.6 2003/04/30 20:03:16 devink Exp $";

/* human readable names for the input module */
char const *IMOD_typeNames[IMOD_TYPECOUNT] = {"BEEP", "UDP", "SYSTEM"};

void
IMOD_setLocalhostInfo(struct message *msg)
{
    char            lhost[HOST_NAME_MAX];
    struct hostent  *hp;


    if (gethostname(lhost, HOST_NAME_MAX) != 0) {
        strlcpy(lhost, "localhost", HOST_NAME_MAX);
    }
    /* make sure this is NUL terminated */
    lhost[HOST_NAME_MAX - 1] = '\0';

    if (msg->host == NULL && msg->hostlen == 0) {
        msg->hostlen = strlen(lhost) + 1;
        msg->host = emalloc(msg->hostlen);
        strlcpy(msg->host, lhost, msg->hostlen);
    }

    if (msg->dfqdnlen == 0 && msg->dfqdn == NULL) {
        hp = gethostbyname(lhost);
        if (hp != NULL) {
            msg->dfqdnlen = strlen(hp->h_name) + 1;
            msg->dfqdn = emalloc(msg->dfqdnlen);
            strlcpy(msg->dfqdn, hp->h_name, msg->dfqdnlen);
        }
    }
}
