/**
 * @file ipc_err.c
 *
 * @brief Implement the functions for dealing with IPC errors.
 * @par
 * @igroup ipc
 *
 *
 * $Id: ipc_err.c,v 1.8.2.1 2003/04/30 20:03:19 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Mon Mar 18 11:49:16 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdlib.h>
#include <stddef.h>
#include <stdio.h>
#include <errno.h>
#include <string.h>

#include "ipc_private.h"
#include "ipc.h"
#include "ipc_err.h"
#include "error.h"

static char const rcsid[] = "$Id: ipc_err.c,v 1.8.2.1 2003/04/30 20:03:19 devink Exp $";

/** Error Messages */
static char const *const errstr[] = {
    "Success",
    "No message waiting",
    "No message of that type waiting",
    "Unknown error",
    "Bad packet format",
    "No such process",
    "I/O error",
    "Bad control packet format",
    "Bad path packet format",
    "Two paths sent by same client at the same time",
    "Bad protocol version",
    "bind/listen",
    "Protocol error",
    "Inputmodule initilization failed",
    "Accept",
    "Can't call this function in the current mode",
    "Unexpected EOF",
    "Bad Path for Unix Domain Socket",
    "Installing Signal Handeler",
    "Unexpected Lock Sub Type", 
    NULL    /* allows commas after all entries. */
};

#define ERR_BUFSZ   512
static char errBuf[ERR_BUFSZ];

int
IPC_geterrno(IPC *handle)
{
    assert(handle != NULL);
    return handle->errcode;
}

char const*
IPC_geterrstr(IPC *handle)
{
    char const   *ipcerr;
    assert(handle != NULL);    

    /* remember errorcodes are actually < 0 */
    if (handle->errcode <= IPCE_COUNT) {
        ipcerr = errstr[-IPCE_ERROR];
    }

    ipcerr = errstr[-(handle->errcode)];

    if (handle->errnocode != 0) {
        snprintf(errBuf, sizeof(errBuf), "%s: %s", 
                ipcerr, strerror(handle->errnocode));

        return errBuf;
    }

    return ipcerr;
}

