/**
 * @file ipc_err.h
 *
 * @brief This header defines the error codes and functions to work with
 * them for the IPC module.
 * @par
 * @ingroup ipc
 *
 *
 * $Id: ipc_err.h,v 1.6.2.1 2003/04/30 20:03:20 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Thu Mar 14 16:30:21 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**@defgroup ipc_errcodes IPC Function Error Code 
 * @ingroup ipc
 */

/** @name IPC function error codes
 * @ingroup ipc_errcodes
 * @{
 */
#define IPCE_SUCCESS    0   /**< Success */
#define IPCE_NOPKT      -1  /**< No packet waiting */
#define IPCE_NOSUCHPKT  -2  /**< No packet of a particular type waiting */
#define IPCE_ERROR      -3  /**< Unknown error */
#define IPCE_BADFMT     -4  /**< Bad packet format */
#define IPCE_NOSUCHPROC -5  /**< No such process */
#define IPCE_IOERROR    -6  /**< I/O Error */
#define IPCE_BADCTRLFMT -7  /**< Bad format of control packet */
#define IPCE_BADPATHFMT -8  /**< Bad format of path packet */
#define IPCE_TWOPATHS   -9  /**< Two incomming paths at the same time */
#define IPCE_BADVER     -10 /**< Bad Protocol Version */
#define IPCE_BINDERR    -11 /**< Error binding/listening to socket */
#define IPCE_PROTERR    -12 /**< protocol error */
#define IPCE_INITFAIL   -13 /**< Inputmodule initilaztion failed */
#define IPCE_ACCEPTERR  -14 /**< Error Accepting a connection */
#define IPCE_BADMODE    -15 /**< Function does work in this IPC::mode */
#define IPCE_UNEOF      -16 /**< Unexpected EOF on read */
#define IPCE_BADPATH    -17 /**< Bad Socket Path */
#define IPCE_SIGINST    -18 /**< Installing Signal Handler failed */
#define IPCE_BADLT      -19 /**< Unexpected Lock Type */

#define IPCE_COUNT      -18 /**< -Count of error messages */
/*@}*/

/**@name IPC Error Code manipulation functions
 * @ingroup ipc
 * @{
 */
/** Get an error code for the last operation.
 * @param handle The IPC handle
 * @return The error code for the last operation.
 *
 * @pre handle != NULL
 */
int IPC_geterrno(IPC *handle);

/** Get a string describing the current error code.
 *  The returned string should not be modified nor should it be
 *  free()ed.  Further the string should be copied if you want to keep
 *  it for more than one call.
 *
 *  @param handle The IPC handle
 *  @return A string describing the last error.
 *
 *  @pre handle != NULL
 */
char const* IPC_geterrstr(IPC *handle);
/*@}*/
