/**
 * @file ipc_lock.h
 *
 * @brief Declare functions which are used in passing locks over the IPC
 * layer.
 *
 * $Id: ipc_lock.h,v 1.1.2.1 2003/04/30 20:03:20 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Sat Jul 13 15:28:56 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef IPC_IPC_LOCK_H
#define IPC_IPC_LOCK_H

#include "ipc.h"

/**@defgroup ipc_lock IPC Lock Passing Low-Level Functions
 * @ingroup ipc
 * @{
 */

/**
 * Send \c lock of type \c lktype to the specified process.  This always
 * sends to the general channel (IPCAC_GENERAL).
 *
 * @param handle The IPC handle to work on.
 * @param lktype The Lock subtype
 * @param lk The Lock to send
 * @param dproc The destination process.
 * @return TRUE on success, FALSE otherwise.
 */
bool IPCLock_send(IPC *handle,IPC_lockType lktype, IPC_lock lk, uint32_t dproc);

/**
 * Recieve the a lock from the queue.  This uses output parameters to
 * pass up the lock information.  If \c src==NULL then it won't be
 * filled in, however, the other out params \b must point to real
 * variables.
 *
 * @param handle The IPC handle to work on.
 * @param src The source of the lock packet (may be \c NULL).
 * @param lktype The Lock sub-type of the recieved packet.
 * @param lk The recieved lock.
 * @return TRUE on sucecs, FALSE otherwise.
 */
bool IPCLock_recv(IPC *handle, struct IPC_addr *src, 
        IPC_lockType *lktype, IPC_lock *lk);

/*@}*/
#endif /* IPC_IPC_LOCK_H */
