/**
 * @file ipc_private.h
 *
 * @brief Some Private data structures for the IPC class.
 *
 * $Id: ipc_private.h,v 1.9.2.1 2003/04/30 20:03:21 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Tue Feb 26 12:03:59 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef IPC_IPC_PRIVATE_H
#define IPC_IPC_PRIVATE_H

#include "types.h"
#include "util/list.h"

#include "ipc_cstate.h"

/**@addtogroup ipc
 * @{
 */

/** 
 * Priority Levels on the waiting message queues maintained by the IPC
 * handle.
 * @internal
 */
typedef enum {
    IPCQ_HIGH = 0,  /**< High priority messages */
    IPCQ_NORM = 1,  /**< Normal priority messages */

    IPCQ_COUNT
} IPC_queuePri;

/** This structure contains the data for an IPC message handle.
 * @internal
 */
struct IPC_object {
    IPC_mode            mode;       /**< mode (Server/Client) */
    uint32_t            paddr;      /**< process address */
    struct IPC_cstate   mainState;  /**< state of the main socket */


    List        queues[IPCQ_COUNT]; /**< Waiting messages queues */

    int                 cliCount;   /**< Number of clients connected */
    struct IPC_cstate   *cliConns;  /**< client info  by process address */

    int                 errcode;    /**< Last error code */
    int                 errnocode;  /**< Last errno code */

    char    sock_path[UNIX_PATH_MAX];   /**< socket path */
};



/*@}*/


#endif /* IPC_IPC_PRIVATE_H */
