/**
 * @file ipc_sig.h
 *
 * @brief IPC Signal handling code.
 *
 *
 * $Id: ipc_sig.h,v 1.2.2.1 2003/04/30 20:03:21 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Fri Jun 21 15:50:55 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef IPC_IPC_SIG_H
#define IPC_IPC_SIG_H

#include "types.h"
#include "ipc.h"

/**@defgroup ipc_sig IPC Signal Handling
 * @ingroup ipc
 * @{
 */

/**
 * Mark a signal as registered with the input waiter stuff.  
 * This primarilly prevents non-IPC module stuff from trying to watch
 * our signals.
 *
 * @param signo The Signal number that we need.
 * @return TRUE on success, FLASE if already registered.
 */
bool INWLL_regSignal(int signo);

/**
 * Setup Signal handling for the IPC layer.  This does setup for the
 * controller.
 *
 * @param handle The IPC handle to work on.
 * @return TRUE on succcess, FALSE otherwise.
 *
 * @pre handle != NULL
 * @post handle->errcode is set to the correct value on error.
 */
bool IPCSig_setupController(IPC *handle);

/**
 * Setup Signal handling for the IPC layer.  This does setup for the
 * input modules.
 *
 * @param handle The IPC handle to work on.
 * @return TRUE on succcess, FALSE otherwise.
 *
 * @pre handle != NULL
 * @post handle->errcode is set to the correct value on error.
 */
bool IPCSig_setupInputModule(IPC *handle);

/**
 * Check for raised but not yet dealt with signals.
 * @note This will not, and MUST NOT, close sockets or try to cleanup
 * an IPC_cstate for a dead process.  Though I have not been successful
 * in getting it, testing shows that it is possible for data to live on
 * the pipe after child death (as expected) so it is the recieving
 * function's responsibility to cleanup the IPC_cstate.
 *
 * @param handle The IPC handle to work with.
 * 
 * @post unexpected child deaths have been queued.
 */
void IPCSig_check(IPC *handle);

/*@}*/
#endif /* IPC_IPC_SIG_H */
