/**
 * @file msg_frmtll.c
 *
 * @brief Implement common formatting functions.
 *
 * $Id: msg_frmtll.c,v 1.2.2.5 2003/04/30 20:03:26 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Wed Aug 28 11:04:40 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifdef HAVE_CONFIG_H
#   include "acconfig.h"
#endif

#include <time.h>
#include "strcompat.h"
#include <stdio.h>

#include "debug.h"

#include "util/bitvec.h"

#include "msg_frmtll.h"
#include "msg_const.h"

static char const rcsid[] 
    = "$Id: msg_frmtll.c,v 1.2.2.5 2003/04/30 20:03:26 devink Exp $";

size_t
MFLL_timestamp(char *buf, size_t sz, time_t timestamp, int tz, uint32_t opts)
{
    struct tm   ltm;
    int         wlen;
    char        *tz_dir;
    int         tz_hr, tz_min;

    localtime_r(&timestamp, &ltm);

    tz_dir = (tz < 0) ? "-" : "+";

    if (tz == MSG_TZ_UNKNOWN) {
        /* fix up the timezone if we can't accuratly say what it is.
         * Everything else is correct becasue MSG_TZ_UNKNOWN is
         * setup that way.
         */
        tz_hr = 0;
        tz_min = 0;
    }
    else {
        if (tz < 0) tz = -tz;
        tz_hr = tz / 60;
        tz_min = tz % 60;
    }

    /* now we format depending on which style of time stamp we are using */
    if (BM_ISSET(opts, MFOPT_RFC3339) ) {


        /* RFC 3339 style time stamp */
        wlen = snprintf(buf, sz, "%.4d-%.2d-%.2dT%.2d:%.2d:%.2d%.1s%.2d:%.2d",
                ltm.tm_year + 1900, ltm.tm_mon + 1, ltm.tm_mday,
                ltm.tm_hour, ltm.tm_min, ltm.tm_sec,
                tz_dir, tz_hr, tz_min);
        
        
    }
    else {
        /* Old Style */
        char    *mdsp = "";
        char    timezone[10];
        char    year[10];
        if (ltm.tm_mday < 10) mdsp = " ";


        year[0] = '\0';
        timezone[0] = '\0';
        if (BM_ISSET(opts, MFOPT_TSYEAR) || BM_ISSET(opts, MFOPT_TSEXT)) {
            snprintf(year, sizeof(year), " %d", ltm.tm_year+1900);
        }

        if (BM_ISSET(opts, MFOPT_TSTZ) || BM_ISSET(opts, MFOPT_TSEXT)) {
            snprintf(timezone, sizeof(timezone), " %.1s%.2d%.2d", tz_dir, tz_hr, tz_min);
        }

        wlen = snprintf(buf, sz, "%s %.1s%d %.2d:%.2d:%.2d%s%s", 
            gMonthNames[ltm.tm_mon], mdsp, ltm.tm_mday, 
            ltm.tm_hour, ltm.tm_min, ltm.tm_sec,
            year, timezone);
    }

    if (wlen > sz || wlen <= 0) 
        return 0;

    return wlen;
}
