/**
 * @file msg_frmtll.h
 *
 * @brief Functions that handle formatting operations common to all the
 * formatters.
 *
 * $Id: msg_frmtll.h,v 1.2.2.7 2003/10/22 04:09:03 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Wed Aug 28 10:59:32 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef MSG_MSG_FRMTLL_H
#define MSG_MSG_FRMTLL_H

#include <sys/types.h>
#include "types.h"

#include "msg_frmt.h"
#include "message.h"

/** Type of a function that can format messages */
typedef size_t (*MFLL_msg_frmt)(char *,size_t,const struct message*,uint32_t);

/** Type of a function that can format paths */
typedef size_t (*MFLL_pth_frmt)(char *,size_t,const struct path*,uint32_t);

/**
 * Convert a message object into a format suitable for rfc3164.
 *
 * @param retstr Buffer for the formatted message in, must be \c retlen bytes
 * @param retlen The sizeof \c retstr
 * @param in The message object to format.
 * @param opts The format options (\c MFRMT_opt::options).
 * @return The number of characters actually written to retstr.
 */
size_t MFLL_rfc3164(char *retstr, size_t retlen, const struct message *in, 
                     uint32_t opts);

/**
 * Convert the internal message struct into the syslog COOKED format
 * defined in RFC3195.
 *
 * @param retstr Buffer for the formatted message.
 * @param retlen The sizeof \c retstr
 * @param in The message object to format.
 * @param opts The format options (\c MFRMT_opt::options).
 * @return The number of characters actually written to retstr.
 */
size_t MFLL_cooked(char *retstr, size_t retlen, const struct message *in,
                   uint32_t opts);

/**
 * Convert the internal path struct into the syslog COOKED format for
 * Path messages defined in RFC 3195
 *
 * @param retstr Buffer for the formatted message.
 * @param retlen The sizeof \c retstr
 * @param in The path object to format.
 * @param opts The format options (\c MFRMT_opt::options)
 * @return The number of characters actuallys written to retstr.
 */
size_t MFLL_cookedPath(char *retstr, size_t retlen, const struct path *in,
                        uint32_t opts);

/**
 * Format the timestamp/timezone into RFC 3164 string representation.
 * Note that tihs rep is used for all types of syslog messages.
 *
 * @param buf The buffer to put the formmated string in
 * @param sz The size of \c buf
 * @param ts The timestamp to format
 * @param tz The timezone to format.
 * @param opts The format options (\c MFRMT_opt::options).
 * @return Number of characters written not including term. NULL
 */
size_t MFLL_timestamp(char *buf, size_t sz, time_t ts, int tz, uint32_t opts);

#endif /* MSG_MSG_FRMTLL_H */
