/**
 * @file msg_parse.h
 *
 * @brief Declare commen parsing functions.
 * @ingroup msg_parse
 *
 * $Id: msg_parse.h,v 1.2.2.6 2003/04/30 20:03:27 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Tue Aug 13 14:36:45 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef MSG_MPARSE_H
#define MSG_MPARSE_H

/**@defgroup msg_parse Message Parsing Functions
 * @ingroup msg
 */

/**@name Parsing Support Functions
 * @ingroup msg_parse
 * These are functions to parse parts of a message.  They are usually
 * used by one or more parser.
 * @{
 */

/**
 * Parse a timestamp into a message object.  If a valid timestamp is not
 * found then we set the timestamp to the current time and return -1.
 * Either way there will be a valid timestamp in \c out when done.
 *
 * @param out The message object to put the timestamp in.
 * @param in The string to parse
 * @param inlen The length of \c in
 * @return number of bytes used, or -1 on error.
 */
int MPARSE_time(struct message *out, char const *in, int inlen);

/**
 * Parse an integer.  This checks for the string to be a valid integer
 * between INT_MIN and INT_MAX.
 *
 * @param out The integer that was parsed
 * @param str The string to parse
 * @return TRUE if str contains a valid integer.
 */
bool MPARSE_strtoi(int *out, char const *str);

/**
 * Parse an unsigned integer.  This checks for the string to be a valid 
 * integer between 0 and UINT_MAX.
 *
 * @param out The integer that was parsed
 * @param str The string to parse
 * @return TRUE if str contains a valid integer.
 */
bool MPARSE_strtoui(unsigned *out, char const *str);

/**
 * Parse an IP address into a netaddr_t object.  If the given string
 * doesnot contain an IP then an error will be returned.
 *
 * @param out a pointer to a netaddr_t ojbect to create
 * @param ip The string containing the IP
 * @return TRUE if \c ip is a valid IP, FALSE otherwise.
 */
bool MPARSE_ip(netaddr_t *out, char const *str);

/*@}*/

#endif /* MSG_MPARSE_H */
