/**
 * @file msg_parse_rfc3164.h
 *
 * @brief UDP (classic syslog) style input parser
 * @par
 * This provides functions to parse a classic syslog style message
 * to the internal message structure format.
 *
 * @design d2_4
 * @ingroup msg_parse_rfc3164
 *
 * $Id: msg_parse_rfc3164.h,v 1.7.2.2 2003/10/22 04:09:03 devink Exp $
 *
 * @author Matt Small <small@sdsc.edu>
 * @date   Thu Mar  7 18:05:44 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef MSG_MPOLD_H
#define MSG_MPOLD_H

#include "message/message.h"

/** @defgroup msg_parse_rfc3164 Old (RFC 3164) Message Parser
 *  @ingroup msg_parse
 *  @{
 */

/** Check the incoming old-style syslogd packet for
 * completeness and format correctness.  By RFC 3164, we check ONLY the PRI
 * and TIMESTAMP fields for correctness.
 *
 * @note If no valid hostname was found, the hostname will be set to NULL and
 * 			the hostlen will be set to 0; this should be corrected by the
 * 			caller.
 *
 * @param in The input string
 * @param out The output message (see message.h)
 * @param inlen	The length of the input string
 * @param ignoreHost Ignore hostname (used for system input)
 * @param udpHacks Tweak behavior for other syslog client compatability.
 * @return >0 on success, <0 on failure
 */
int		MPOLD_parsein(struct message *out,char *in,int inlen,
			bool ignoreHost, bool udpHacks);

/*@}*/
#endif
