/**
 * @file omod_init.h
 *
 * @brief This cotains functions declarations for each output module
 * types' interface initilization function.
 *
 * $Id: omod_init.h,v 1.3.2.6 2003/04/30 20:03:32 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Wed Jul 24 19:30:14 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef OMOD_OMOD_INIT_H
#define OMOD_OMOD_INIT_H

#include "outputmod.h"

/**
 * Structure that contains output module registration inforamtion.
 * @ingroup omod
 */
struct OMOD_registration 
{
    /** 
     * Fill in an OMOD_interface with the correct information.
     * @param iface The OMOD_interface object to fill in.
     */
    void (*iface_init)(OMOD_interface *iface);

    /** 
     * Process the OMOD_opts information prior to being passed into the
     * output modules initilization function.  This will be done prior
     * to the call of OMOD_interface::INIT()
     *
     * This is the function that OMOD_processOptions calls to do it's
     * job.
     *
     * @see OMOD_processOptions() for a description of what this
     * should/can do.
     *
     * @param opts The options to check
     * @param f The file to print with error messages.
     * @param l The line to print with error messages.
     * @return FALSE on fatal error, TRUE otherwise.
     */
    bool (*process_opts)(struct OMOD_opt *opts, char const *f, int l);
};

/** 
 * Initializes an OMOD_interface to point to the correct functions; and
 * sets the state member to NULL.
 * @ingroup omod_file
 *
 * @param iface the interface to initialize
 */
void OMOD_FR_iface_init(OMOD_interface *iface);

/**
 * Process options for the file output module.
 * @ingroup omod_file
 *
 * @param opts The options to check
 * @param f The file to print with error messages.
 * @param l The line to print with error messages.
 * @return FALSE on fatal error, TRUE otherwise.
 */
bool OMOD_FR_process_opts(struct OMOD_opt *opts, char const *f, int l);

/**
 * Initilize an OMOD_interface for a udp output module.
 * @ingroup omod_udp
 *
 * @param iface The interface to initilize.
 */
void OMOD_UDP_iface_init(OMOD_interface *iface);

/**
 * Process options for the UDP output module.
 * @ingroup omod_udp
 *
 * @param opts The options to check
 * @param f The file to print with error messages.
 * @param l The line to print with error messages.
 * @return FALSE on fatal error, TRUE otherwise.
 */
bool OMOD_UDP_process_opts(struct OMOD_opt *opts, char const *f, int l);

/**
 * Initilize an OMOD_interface for a console output module.
 * @ingroup omod_cons
 *
 * @param iface The interface to initilize.
 */
void OMOD_CONS_iface_init(OMOD_interface *iface);

/**
 * Process options for the console output module.
 * @ingroup omod_cons
 *
 * @param opts The options to check
 * @param f The file to print with error messages.
 * @param l The line to print with error messages.
 * @return FALSE on fatal error, TRUE otherwise.
 */
bool OMOD_CONS_process_opts(struct OMOD_opt *opts, char const *f, int l);

/**
 * Initialize an OMOD_interface for a BEEP output module.
 * @ingroup omod_br
 *
 * @param iface The interface to initialize.
 */
void OMOD_BP_iface_init(OMOD_interface *iface);

/**
 * Process options for the BEEP output module.
 * @ingroup omod_br
 *
 * @param opts The options to check
 * @param f The file to print with error messages.
 * @param l The line to print with error messages.
 * @return FALSE on fatal error, TRUE otherwise.
 */
bool OMOD_BP_process_opts(struct OMOD_opt *opts, char const *f, int l);

/**
 * Initilize on OMOD_interface for a USER output module.
 * @ingroup omod_user
 *
 * @param iface The interface to initilize.
 */
void OMOD_USER_iface_init(OMOD_interface *iface);

/**
 * Process options for the USER output module.
 * @ingroup omod_user
 *
 * @param opts The options to check
 * @param f The file to print with error messages.
 * @param l The line to print with error messages.
 * @return FALSE on fatal error, TRUE otherwise.
 */
bool OMOD_USER_process_opts(struct OMOD_opt *opts, char const *f, int l);

#endif /* OMOD_OMOD_INIT_H */
