/**
 * @file chkusleep.c
 *
 * @brief A program to check the minimum amount of time that can be
 * slept on. 
 *
 * $Id: chkusleep.c,v 1.1.2.2 2003/04/30 20:03:36 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Thu Sep 26 16:31:36 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <unistd.h>
#include <stdio.h>
#include "common.h"

#define TRIES_PER_TARGET    100
#define START_TARGET        1
#define GIVEUP_TARGET       1000000

#define OUT_HEADER  "Target  \tAve \tMin \tMax\n"
#define OUT_LINE    "%.2E    \t%.2G\t%.2G\t%.2G\n"

#define CLOCK_HZ (double)sysconf(_SC_CLK_TCK)

#define DELAY_LOOP(intv)  \
    {int i; unsigned long count; \
        count=(unsigned long)(((double)intv * 1e6)/(10*CLOCK_HZ)); \
        for (i = 0; i < count; i++) ; }

int main(void)
{
    struct TIME_ctx     timer;
    unsigned long       target_interval;
    double              actual_interval;
    double              interval_sum;
    double              interval_max;
    double              interval_min;
    int                 i;

    target_interval = START_TARGET;

    printf(OUT_HEADER);

    while (target_interval < GIVEUP_TARGET) {
        interval_sum = 0.0;
        interval_max = 0.0;
        /* should be big enough so _min gets set */
        interval_min = target_interval * 1e6;   

        for (i = 0; i < TRIES_PER_TARGET; i++) {
            TIME_start(&timer, TIME_WC);

            DELAY_LOOP(target_interval)

            TIME_wc_stop(&timer);
            actual_interval = TIME_wcinterval(&timer);
            if (actual_interval < interval_min) 
                interval_min = actual_interval;
            if (actual_interval > interval_max)
                interval_max = actual_interval;
            interval_sum += actual_interval;
        }

        /* use interval sum to hold the average */
        interval_sum /= TRIES_PER_TARGET;

        printf(OUT_LINE, (double)(target_interval/1e6), interval_sum,
                interval_min, interval_max);

        /* Just double it for now */
        target_interval *= 2;

    }

    return 0;
}

