/**
 * @file trafgen.c
 *
 * @brief Generate traffic at a semi constant rate.
 * @par
 * This generates traffic via the normal syslog interface.
 *
 *
 * $Id: trafgen.c,v 1.1.2.2 2003/04/30 20:03:36 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Thu Oct 31 13:43:17 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <syslog.h>
#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>

#define MAX_SLEEP_TIME  90

int main(void)
{
    pid_t           pid;
    int             fd;
    unsigned long   msgNum;

    /* daemonize first */
    if (chdir("/") < 0) {
        perror("chdir");
        exit(1);
    }

    /* Fork */
    pid = fork();
    if (pid < 0) {
        perror("fork");
        exit(1);
    }
    else if (pid > 0) {
        exit(0);
    }

    /* cleanup STDIO stuff */
    fd = open("/dev/null", O_RDONLY|O_NONBLOCK);
    if (fd < 0) {
        perror("open");
        exit(1);
    }
    if (dup2(fd, STDIN_FILENO) == -1 
        || dup2(fd, STDOUT_FILENO) == -1
        || dup2(fd, STDERR_FILENO) == -1)
    {
        perror("dup2");
        exit(1);
    }
    close(fd);

    /* detach from controlling tty */
    fd = open("/dev/tty", O_RDWR);
    if (fd >= 0) {
        if (ioctl(fd, TIOCNOTTY, 0) < 0) {
            perror("ioctl");
            exit(1);
        }
        close(fd);
    }

    openlog("trafgen", LOG_PID, LOG_LOCAL7);
    msgNum = 0;
    for (;;) {
        syslog(LOG_INFO, "Test Message %lu", msgNum);
        msgNum++;

        sleep(rand() % MAX_SLEEP_TIME);
    }
    /* NOT REACHED */
    closelog();
    return 0;
}
