/**
 * @file ut_base.h
 *
 * @brief Declare the suite setup functions for the base unit tests.
 *
 * $Id: ut_base.h,v 1.3.2.5 2003/04/30 20:03:44 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Tue Feb 05 16:53:32 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef TEST_UNIT_BASE_H
#define TEST_UNIT_BASE_H


/**@defgroup utb_llist Linked List Tests
 * @ingroup ut_base
 * @{
 */

/** Setup the list test suite 
 * @param suite The test suite to setup.
 */
void list_suite(Suite *suite);
/*@}*/

/**@defgroup utb_netaddr Network Address Abstraction Tests
 * @ingroup ut_base
 * @{
 */

/** Setup the netaddr test suite
 * @param suite The test suite to setup.
 */
void netaddr_suite(Suite *suite);

/*@}*/

/**@defgroup utb_buffer Buffer Tests
 * @ingroup ut_base
 * @{
 */

/** Setup the buffer test suite
 * @param suite The test suite to setup
 */
void buffer_suite(Suite *suite);

/*@}*/

/**@defgroup utb_pathcache Path Cache Tests
 * @ingroup ut_base
 * @{
 */
void pathcache_suite(Suite *suite);
/*@}*/

/**@defgroup utb_common_funcs Common Function Tests
 * @ingroup ut_base
 * @{
 */
void cf_suite(Suite *suite);
/*@}*/


#endif /* TEST_UNIT_BASE_H */
