/**
 * @file common_funcs.h
 *
 * @brief Common functions to several unit tests
 * @par
 *
 * $Id: common_funcs.h,v 1.1.2.6 2003/04/30 20:03:41 devink Exp $
 *
 * @author Matt Small <small@sdsc.edu>
 * @date   Thu Sep  5 14:44:01 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**@name Common functions
 * @ingroup unit_test
 * @{
 */

/** Compare two struct message objects
 * A value of -1 in the timestamp field indicates to the function that both the
 * timestamp and the timezone fields should be ignored, and not checked.
 *
 * @param a The first message to compare
 * @param b The second message to compare
 */
#define CMP_msg(a,b) internal_msgCompare(a,b,__FILE__,__LINE__)

/** Compare two struct message objects
 * Do not use this; instead, use msgCompare()
 *
 * @internal
 *
 * @param a The first message to compare
 * @param b The second message to compare
 * @param file The filename this was called from
 * @param line The line number this was called from
 */
void internal_msgCompare(struct message *a,struct message *b,char *file,
		int line);

/** Compare two path objects
 *
 * @param a The first path
 * @param b The second path
 */
#define CMP_path(a,b) internal_CMP_path(a,b,__FILE__,__LINE__)

/** Compare two path objects
 * Do not use this; instead, use CMP_path()
 *
 * @internal
 *
 * @param a The first path
 * @param b The second path
 * @param file The filename this was called from
 * @param line The line number this was called from
 */
void internal_CMP_path(struct path *a,struct path *b,char *file,int line);

/** Return the timezone (in the format used by the tz field of messages
 *
 * @return The current timezone
 */
int getTZ(void);

/*@}*/
