/**
 * @file ut_ipc.c
 *
 * @brief IPC Library Test Driver
 * @ingroup ut_ipc
 *
 *
 * $Id: ut_ipc.c,v 1.13.2.6 2003/04/30 20:03:50 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Fri Mar 29 15:43:31 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/types.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <errno.h>

#include "check.h"
#include "util/tsqueue.h"

#include "ipc/ipc.h"
#include "ipc/ipc_err.h"
#include "ipc/ipc_ctl.h"
#include "ipc/inputwait.h"

#include "debug.h"

#include "ut_ipc.h"
#include "ut_driver.h"

/**@name Globals needed by generic test driver
 * @ingroup ut_ipc
 * @{
 */

SuiteInfo suites[] = {
    ADD_SUITE(buffer_suite, "IPCBuffer"),
	ADD_SUITE(waiter_suite, "IW"),
	ADD_SUITE(waiter_fork_suite, "IW_Fork"),
    ADD_SUITE(ipc_init_suite, "IPC_Init"),
    ADD_SUITE(ipc_msg_suite, "IPC_Messages"),
    ADD_SUITE(ipc_lock_suite, "IPC_Lock"),
    ADD_SUITE(ipc_sig_suite, "IPC_Signal"),
};

int suite_count = SUITE_COUNT;

char const *log_name = "ipc";

bool disablePrivs = TRUE;
/*@}*/

IPC *ctlrHandle;
IPC *cliHandle;
INW *waiter;

void ipc_init_ctlr(void)
{
    char    msg[1024];

    ctlrHandle = IPC_initController(SOCK_PATH);
    if (IPC_geterrno(ctlrHandle) != IPCE_SUCCESS) {
        snprintf(msg, sizeof(msg),
            "Controler Init failed (%d), %s",
            IPC_geterrno(ctlrHandle),
            IPC_geterrstr(ctlrHandle)); 


        IPC_destroy(ctlrHandle);
        ctlrHandle = NULL;

        fail(msg);
    }
    INW_initialize();
    waiter = INW_create();
    INW_addIPC(waiter, ctlrHandle);
}

void ipc_destroy_ctlr(void)
{
    if (ctlrHandle != NULL) {
        INW_destroy(&waiter);
        IPC_destroy(ctlrHandle);
        ctlrHandle = NULL;
    }

    INW_shutdown();
}

void ipc_init_client(void)
{
    char    msg[1024];

    sleep(2);

    cliHandle = IPC_initInputModule(SOCK_PATH);
    if (IPC_geterrno(cliHandle) != IPCE_SUCCESS) {
        snprintf(msg, sizeof(msg),
            "Client Init failed (%d), %s",
            IPC_geterrno(cliHandle),
            IPC_geterrstr(cliHandle));

        IPC_destroy(cliHandle);
        cliHandle = NULL;

        fail(msg);
    }
    INW_initialize();
    waiter = INW_create();
    INW_addIPC(waiter, cliHandle);
}

void ipc_destroy_client(void)
{
    if (cliHandle != NULL) {
        INW_destroy(&waiter);

        IPC_inputmoduleExit(cliHandle);

        IPC_destroy(cliHandle);
        cliHandle = NULL;
    }

    INW_shutdown();
}

void
debug_done(void)
{
    DPRINT(DBG_DBG, "Test Case Done", NO_VARG);
}

