/**
 * @file ut_ipc.h
 *
 * @brief Declare the functions which are required to setup the IPC test
 *        suite.
 * @ingroup ut_ipc
 *
 *
 * $Id: ut_ipc.h,v 1.8.2.5 2003/04/30 20:03:51 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Fri Mar 29 16:00:21 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef TEST_UNIT_IPC_H
#define TEST_UNIT_IPC_H

#include "check.h"
#include "ipc/ipc.h"
#include "ipc/inputwait.h"

/**@defgroup ut_ipc IPC Tests 
 * @ingroup unit_test
 * @{
 */

/** 
 * Setup the IPC initilization/destruction test suite
 * @param suite The test suite object to setup.
 */
void ipc_init_suite(Suite *suite);

/**
 * Setup the IPCBuffer suite
 * @param suite the Suite to fill in.
 */
void buffer_suite(Suite *suite);

/**
 * Setup the message passing test cases
 * @param suite the Suite to fill in.
 */
void ipc_msg_suite(Suite *suite);

/**
 * Setup the IPC Signal test cases.
 * @param suite the Suite to fill in.
 */
void ipc_sig_suite(Suite *suite);

/**
 * Setup the IPC Lock Passing test cases.
 * @param suite The Suite to fill in.
 */
void ipc_lock_suite(Suite *suite);

/**
 * Setup the Input Waiter test suite
 * @param suite The suite to setup
 */
void waiter_suite(Suite *suite);

/**
 * Setup the Input Waiter Forking test suite
 * @param suite The suite to setup
 */
void waiter_fork_suite(Suite *suite);

/*@}*/

/**@name IPC Test Helpers 
 * @ingroup ut_ipc
 * @{
 */


/** Max Number of test clients */
#define IPC_TEST_CLI_COUNT  10

/** Wait time for reads (in seconds) */
#define WAIT_TIMEOUT    10

/** the controller handle, which can be used by test cases, and will be
 * setup for them
 */
extern IPC *ctlrHandle;

/** The client handle of the current process */
extern IPC *cliHandle;

/** The Input Waiter to use */
extern INW *waiter;

/** The socket path to use for our tests */
#define SOCK_PATH "ut_ipc_test.sock"

/** Initilize the specified IPC client, will fail on error.  */
void ipc_init_client(void);

/** Destroy all the Client IPC handle, via graceful shutdown */
void ipc_destroy_client(void);

/** Initilize the controller side of the IPC layer */
void ipc_init_ctlr(void);

/** Destroy all the Controller IPC handle, via graceful shutdown */
void ipc_destroy_ctlr(void);

/** 
 * Debugging teardown function, this can be shared because it doesn't
 * need a separate log name.
 */
void debug_done(void);

/*@}*/

#endif /* TEST_UNIT_IPC_H */
