/**
 * @file ut_msg_parser_old.c
 *
 * @brief 
 * @par
 *
 *
 * $Id: ut_msg_parser_old.c,v 1.8.2.3 2003/10/22 04:09:04 devink Exp $
 *
 * @author Matt Small <small@sdsc.edu>
 * @date   Thu Aug 22 16:33:51 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include <stdio.h>
#include <time.h>
#include <string.h>
#include <stdlib.h>

#include "check.h"
#include "message/message.h"
#include "message/msg_parse_rfc3164.h"
#include "message/msg_parse.h"

#include "debug.h"

/** The number and size of test elements */
#define MAXLEN		1024

/*
void dumpmsg(FILE *stream,struct message *msg);

void dumpmsg(FILE *stream,struct message *msg)
{
	fprintf(stream,"sev: %d\tfac: %d\tpri: %d\n",msg->sev,msg->fac,8*msg->fac+msg->sev);
	fprintf(stream,"hostlen: %d\thost: \'%s\'\n",msg->hostlen,msg->host);
	fprintf(stream,"timestamp: %s",ctime(&(msg->timestamp)));
	fprintf(stream,"tz: %d\t",msg->tz);
	fprintf(stream,"tag: \'%s\'\n",msg->tag);
	fprintf(stream,"msglen: %d\tmsg: \'%s\'\n",msg->msglen,msg->msg);
}
*/

/**@name Message Parser Test Cases
 * @ingroup ut_msg_parse
 * @{
 */

/** Test UDP (old-style syslog) message parsing */
static void TESTmsg_parse_old(void);

/** Test compatability with screwed up older syslog message formats */
static void TESTmsg_parse_compat(void);

/*@}*/

/**@defgroup ut_msg_parse_impl Message Parser Test Cases Implementation
 * @ingroup ut_msg_parse
 * @{
 */

static void
debug_init(void)
{
    DBG_init("m", "msg-parse-old.debug");
}

static void
debug_done(void)
{
    DPRINT(DBG_DBG, "Test Case Done", NO_VARG);
}

/* test suite setup */
void msg_parse_old_suite(Suite *suite)
{
	TCase *tc_msg;

	tc_msg = tcase_create("MParser_Old");
	suite_add_tcase(suite,tc_msg);

    tcase_add_unchecked_fixture(tc_msg, debug_init, debug_done);

	tcase_add_test(tc_msg,TESTmsg_parse_old);
    tcase_add_test(tc_msg,TESTmsg_parse_compat);
}

static void
testmessages(struct message *checkmsgs, char ins[][MAXLEN], int numtests, bool udpHacks) 
{
	char failmsg[1024];
	int i=0;
	struct message retmsg;

	for(i=0;i<numtests;i++)
	{
        DPRINT(DBG_DBG, "test: about to parse '%s'", ins[i]);
		(void)MPOLD_parsein(&retmsg,ins[i],strlen(ins[i])+1, FALSE, udpHacks);

		snprintf(failmsg,1024,"checkmsgs[%d].sev (%d)!=retmsg.sev (%d)",
				i,checkmsgs[i].sev,retmsg.sev);
		fail_unless(checkmsgs[i].sev==retmsg.sev,failmsg);

		snprintf(failmsg,1024,"checkmsgs[%d].fac (%d)!=retmsg.fac (%d)",
				i,checkmsgs[i].fac,retmsg.fac);
		fail_unless(checkmsgs[i].fac==retmsg.fac,failmsg);

		snprintf(failmsg,1024,
                "checkmsgs[%d].hostlen (%d)!=retmsg.hostlen (%d: '%s')",
				i,checkmsgs[i].hostlen,retmsg.hostlen, retmsg.host);
		fail_unless(checkmsgs[i].hostlen==retmsg.hostlen,failmsg);

		snprintf(failmsg,1024,"retmsg.host (test %d) unexpected: %s",
				i,retmsg.host);
        if (checkmsgs[i].host == NULL) {
            fail_unless(retmsg.host == checkmsgs[i].host, failmsg);
        }
        else {
            fail_unless(0==strncmp(retmsg.host,checkmsgs[i].host,checkmsgs[i].hostlen),failmsg);
        }

		if(checkmsgs[i].timestamp!=0)
		{
			snprintf(failmsg,1024,"checkmsgs[%d].timestamp (%lu) != retmsg.timestamp (%lu)",
					i,checkmsgs[i].timestamp,retmsg.timestamp);
			fail_unless(checkmsgs[i].timestamp==retmsg.timestamp,failmsg);
		}

		if(checkmsgs[i].tz!=0)
		{
			snprintf(failmsg,1024,"checkmsgs[%d].tz (%d) != retmsg.tz (%d)",
					i,checkmsgs[i].tz,retmsg.tz);
			fail_unless(retmsg.tz==checkmsgs[i].tz,failmsg);
		}

		snprintf(failmsg,1024,"checkmsgs[%d].tag (%s) != retmsg.tag (%s)",
				i,checkmsgs[i].tag,retmsg.tag);
		fail_unless(0==strncmp(retmsg.tag,checkmsgs[i].tag,MSGTAG_LEN),failmsg);

		snprintf(failmsg,1024,"checkmsgs[%d].msglen (%d) != retmsg.msglen (%d)",
				i,checkmsgs[i].msglen,retmsg.msglen);
		fail_unless(checkmsgs[i].msglen==retmsg.msglen,failmsg);

		snprintf(failmsg,1024,"retmsg.msg (test %d) unexpected: %s",
				i,retmsg.msg);
		fail_unless(0==strncmp(retmsg.msg,checkmsgs[i].msg,retmsg.msglen),failmsg);

		if(retmsg.host!=NULL)
			free(retmsg.host);
		free(retmsg.msg);
	}
}

/* Test compatability with older syslog clients and our parser */
START_TEST(TESTmsg_parse_compat)
{
#define NUMTESTS 3
/* Becasue we are testing a limited range of problems, all time
 * stamps/hosts are the same ... so we just #define to make things easy.
 */
#define TS "Nov 11 22:14:15"
#define HOST "syslog0"
    char ins[NUMTESTS][MAXLEN] = {
        {"<35>devink: testing 1 2 3 4", },
        {"<35>" TS " devink: testing 1 2 3 4",},
        {"<35>" HOST " devink: testing 1 2 3 4", },
    };
    struct message basemsg = 
        {3, 4, 0, NULL, 0, 0, "devink", 18, ": testing 1 2 3 4", };
    struct message checkmsgs[NUMTESTS] = {basemsg, basemsg, basemsg};

    /* Set the timestamp on this message */
    MPARSE_time(&(checkmsgs[1]), TS,  strlen(TS)+1);

    /* and the host on this one */
    checkmsgs[2].hostlen = 8;
    checkmsgs[2].host = HOST;

    testmessages(checkmsgs, ins, 3, TRUE);
#undef NUMTESTS
}
END_TEST

START_TEST(TESTmsg_parse_old)
{
#define	NUMTESTS	8
	char ins[NUMTESTS][MAXLEN]={
		{ "<35>Nov 11 22:14:15 buckaroo su: 'su root' failed for lonvick", },
		{ "<>Nov 11 22:14:15 buckaroo su: 'su root' failed for small", },
		{ "<72>1980-11-11T22:14:15-06:00 192.168.12.12 su[12]: 'su root' failed for small", },
		{ "<72>1980-11-11T22:14:15-06:00 asdf", },
		{ "<72>1980-11-11T23:14:15-06:00 asdf su", },
		{ "<72>1980-11-11T00:14:15-06:00 asdf su", },
		{ "<72>1981-11-11T00:14:15-06:00 asdf su", },
		{ "<72>2002-06-05T16:36:06+04:30 192.168.12.1 syslogd[3267]: started working", },
	};
	struct message checkmsgs[NUMTESTS]={
		/*S, F, HL, H, T, TZ, TA, ML, M */
		{ 3, 4, 9, "buckaroo", 0, 0, "su", 31, ": 'su root' failed for lonvick", },
		{ 5, 1, 0, NULL,0, 0, "",  
#if ENABLE_UNPARSABLE_MARK
            69, " UNPARSABLE<>Nov 11 22:14:15 buckaroo su: 'su root' failed for small",
#else
            58, "<>Nov 11 22:14:15 buckaroo su: 'su root' failed for small", 
#endif  
            },
		{ 0, 9, 14, "192.168.12.12", 342857655, -360, "su", 33, "[12]: 'su root' failed for small", },
		{ 0, 9, 5, "asdf", 342857655, -360, "", 0, NULL, },
		{ 0, 9, 5, "asdf", 342861255, -360, "su", 0, NULL, },
		{ 0, 9, 5, "asdf", 342778455, -360, "su", 0, NULL, },
		{ 0, 9, 5, "asdf", 374314455, -360, "su", 0, NULL, },
		{ 0, 9, 13, "192.168.12.1", 1023320166, 270, "syslogd", 24,"[3267]: started working", },
	};

    testmessages(checkmsgs, ins, NUMTESTS, FALSE);
#undef NUMTESTS
}
END_TEST


/*@}*/

