/**
 * @file ut_omod_fread.c
 *
 * @brief Reabable File Format output tests
 * @par
 *
 *
 * $Id: ut_omod_fread.c,v 1.11.2.7 2003/10/22 04:09:04 devink Exp $
 *
 * @author Matt Small <small@sdsc.edu>
 * @date   Thu May  9 16:21:54 PDT 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>

#include "error.h"
#include "debug.h"
#include "check.h"
#include "privs.h"
#include "util/bitvec.h"
#include "message/message.h"
#include "message/msg_parse_rfc3164.h"
#include "message/msg_frmt.h"
#include "outputmod/outputmod.h"

#define	NUMTESTS	2
#define	MAXLEN		1024

/**@name Output Module File (Readable format) Test Cases
 * @ingroup ut_omod_fread
 * @{
 */

/** Test readable output */
static void TESTomod_fread_sndmsg(void);

/*@}*/

/**@defgroup Output Module File (Readable format) Test Case Implementation
 * @ingroup ut_omod_fread
 * @{
 */

/* test suite setup */
void omod_fread_suite(Suite *suite)
{
	TCase *tc_io;

	tc_io=tcase_create("OMOD_FILE_Readable");
	suite_add_tcase(suite,tc_io);

	tcase_add_test(tc_io,TESTomod_fread_sndmsg);
}

/* this is meant to be read from the base unit directory */
#define TESTomod_fread_fname1	"ut_omod_fread_test1.out"
START_TEST(TESTomod_fread_sndmsg)
{
	char ins[NUMTESTS][MAXLEN]={
		{ "<62>2001-11-11T03:07:12+08:00 buckaroo su: 'su root' failed for lonvick",},
		{ "<72>2002-01-12T04:07:12+04:00 buckaroo identd[76]: server got SIGHUP",},
	};
	char expout[NUMTESTS][MAXLEN]={
		{ "2001-11-11T03:07:12+08:00 buckaroo su: 'su root' failed for lonvick",},
		{ "2002-01-12T04:07:12+04:00 buckaroo identd[76]: server got SIGHUP",},
	};
	char outmsg[MAXLEN];
	struct message parsedmsg;

	struct OMOD_opt options;
	OMOD_interface *iface;
	struct OMOD_state *state;

	int i;
	int fdes;
	int j; char c;

	PRIV_disableChanges();

    DBG_init("m", "omod-fread.debug");

	/* init */
    options.format.type = MFRMT_RFC3164; 
    options.format.options = 0;
    BM_SET(options.format.options, MFOPT_RFC3339); 

	options.outPath = TESTomod_fread_fname1;
    iface = OMOD_getInterface(OMOD_FILE);

    /* Make sure that we don't have a stale one interfearing. */
    unlink(TESTomod_fread_fname1);

	/* let's start using the functions; here's where the test is */
	state=iface->INIT(&options);

	for(i=0;i<NUMTESTS;i++)
	{
		MPOLD_parsein(&parsedmsg,ins[i],strlen(ins[i])+1, FALSE, FALSE);

		iface->SEND_MSG(state,&parsedmsg);
	}

	iface->DESTROY(state);

	/* now, let's check our work */
	fdes=open(TESTomod_fread_fname1,O_RDONLY);
	for(i=0;i<NUMTESTS;i++)
	{
		j=0;
		while(j<MAXLEN)
		{
			read(fdes,&c,1);
			if(c=='\n' || c=='\0')
				break;

			outmsg[j]=c;
			j++;
		}
		outmsg[j]='\0';


        if (strncmp(outmsg, expout[i], MAXLEN) != 0) {
            char    buf[4096];
            snprintf(buf, sizeof(buf), 
                    "File output (%s) didn't match expectations (%s)", 
                    outmsg, expout[i]);
            fail(buf);
        }
	}
	close(fdes);

    /* Cleanup after ourselves */
    unlink(TESTomod_fread_fname1);
}
END_TEST
#undef TESTomod_fread_fname1

/*@}*/
