/**
 * @file acl_private.h
 *
 * @brief The internals of the acl library.  
 * @par
 * This is where internal data structures are declared.  
 * @internal
 * @ingroup acl
 *
 * $Id: acl_private.h,v 1.4.2.1 2003/04/30 20:03:59 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Tue Jan 29 15:48:42 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef ACL_ACL_PRIVATE_H
#define ACL_ACL_PRIVATE_H

#include "netaddr.h"
#include "list.h"

/**@name ACL Internal Structures
 * @addtogroup acl 
 * @{
 */

/** A union for holding %ACL data.
 * @internal
 */
typedef union {
    netaddr_t           addr;       /**< network address */
    uint32_t            linkProps;  /**< bitmap of link props */
} ACL_data;

/** Hold the data needed for one type of ACL. This can be treated as an
 * opaque structure by clients.
 * @internal
 */
typedef struct {
    ACL_type    type;       /**< \ref acl_types value */
    ACL_mode    mode;       /**< \ref acl_modes value */
    List        list;       /**< The actual %ACL data */
} ACL;

/** The %ACL library state object. As far as the client is concerned this
 * is opaque.  
 * @internal
 */
typedef struct 
{
    ACL     *acls[ACLT_COUNT];
} ACLChecker;

/*@}*/

#endif /* ACL_ACL_PRIVATE_H */

