/**
 * @file error.c
 *
 * @brief Implement functions for error handling
 *
 *
 * $Id: error.c,v 1.9.2.1 2003/04/30 20:04:01 devink Exp $
 *
 * @author Devin Kowatch <devink@sdsc.edu>
 * @date   Tue Feb 05 12:38:04 PST 2002
 *
 * Copyright 2002-2003 
 *     The Regents of the University of California. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 * 
 *     * Neither the name of the The Regents of the University of
 *       California nor the names of its contributors may be used to
 *       endorse or promote products derived from this software without
 *       specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifdef HAVE_CONFIG_H
#   include "acconfig.h"
#endif

#include <stdlib.h>
#include <stdio.h>
#include <errno.h>

#include "error.h"
#include "debug.h"
#include "log.h"

#ifdef WITH_DMALLOC
	#include <dmalloc.h>
#endif

static char const rcsid[] = "$Id: error.c,v 1.9.2.1 2003/04/30 20:04:01 devink Exp $";

void *
errorMalloc(char const *file, int line, size_t size)
{
    void    *rtn;

#ifdef WITH_DMALLOC
	rtn = _malloc_leap(file,line,size);
#else
	rtn = malloc(size);
#endif

    if (rtn == NULL) {
        /*throwFatal(file, line, "malloc() failed");*/
		throwFatal(file,line, strerror(errno));
    }

    return rtn;
}

void
throwFatal(char const *file, int line, char const *msg)
{
    LOG_print(LOG_CRIT, msg);
    DBG_printfatal(msg, file, line);
    abort();
}

