#!/bin/sh
# 
# File: vers.sh
#
#
# Description: This script is run to create the version.h file.
#
# $Id: vers.sh,v 1.7.2.9 2003/04/30 20:02:56 devink Exp $
#
# Author: Devin Kowatch <devink@sdsc.edu>
# Date: Mon Jul 22 16:19:41 PDT 2002
#
# Copyright 2002-2003 
#     The Regents of the University of California. All Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
# 
#     * Neither the name of the The Regents of the University of
#       California nor the names of its contributors may be used to
#       endorse or promote products derived from this software without
#       specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

#set -x 

top_srcdir='.'
case "$1" in 
    --top_srcdir=*)
        top_srcdir=`echo $1 | sed 's/--top_srcdir=//'`
        shift
        ;;
esac

TAGFUNCS="${top_srcdir}/relsup/tag_funcs.sh"
test -r "$TAGFUNCS" || (echo "Can't find taging support functions" 1>&2;exit 1) 
. $TAGFUNCS

# This will only help on a tagged release (not a branch)
RELTAG=`echo '$Name: SYSLOGD_1_0_2_RELEASE $' | sed 's/$\Name: *\(.*\)\\$/\1/'`
if test "x$RELTAG" = "x" ; then
    if test ! -r "${top_srcdir}/VERSION" ; then
        echo "Can't find VERSION file" 1>&2
        exit 1
    fi
    . $top_srcdir/VERSION
    
    if test "x$BRANCH" = "xhead" ; then
        RELTAG="HEAD_${head_ver}"
    elif test "x$BRANCH" = "xstable" ; then
        RELTAG="${TAG_PREFIX}_${stable_ver}"
    elif test "x$BRANCH" = "xpatch" ; then
        RELTAG="${TAG_PREFIX}_${patch_ver}"
    else
        echo "Invalid branch name '$BRANCH'" 1>&2
        exit 1
    fi
fi

AWK_GETVER="BEGIN { FS = \"_\" }
/$TAGRE_RELEASE/    { printf \"%d.%d.%d -RELEASE\", \$2, \$3, \$4; next; }
/$TAGRE_RC/         { printf \"%d.%d.%d -%s\", \$2, \$3, \$4, \$5; next; }
/$TAGRE_PATCH/      { printf \"%d.%d -PATCH\", \$2, \$3; next; }
/$TAGRE_STABLE/     { printf \"%d -STABLE\", \$2; next; }
/HEAD_[0-9]*/       { printf \"%d -UNSTABLE\", \$2; next; }
/.*/                { print \"no\"; }"


build_date=`date `
version=""
branch=""
release=1
tmp=`echo $RELTAG | awk -- "$AWK_GETVER"`
if test "x$tmp" = "xno" ; then
    echo "Can't determine version" 1>&2
    exit 1
fi

version=`echo $tmp | sed 's/\([^ ]*\) [^ ]*/\1/'`
branch=`echo $tmp | sed 's/[^ ]* \([^ ]*\)/\1/'`

if test "x$branch" = "x" \
    || test "x$branch" = "x-STABLE" \
    || test "x$branch" = "x-UNSTABLE"
then
    release=0
fi

verfile_in="$1"

if test "x$verfile_in" = "x" ;then
    echo "No version file given, dumping vars"
    echo "VERSION: $version"
    echo "BRANCH: $branch"
    echo "BUILD: $build_date"
    echo "RELEASE: $release"
    
    exit 0
fi
verfile=`echo $verfile_in | sed 's,\.in,,'`

sed -e "s/@VERSION@/$version/"  \
    -e "s/@BRANCH@/$branch/"    \
    -e "s/@BUILD_DATE@/$build_date/" \
    -e "s/@RELEASE@/$release/"  \
    $verfile_in > $verfile
